==> ejc-ztpcdc-impl-3.0.0-20230608.013305-63-sources.jar: com/ejianc/business/dc/bean/DcChangemanageInfoEntity.java <==
package com.ejianc.business.dc.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.dc.bean.DcChangemanageDrawinfoEntity;
import com.ejianc.business.dc.bean.DcChangemanageInfoEntity;
/**
 * 变更管理表
 * 
 * @author generator
 * 
 */
 @TableName("dc_changemanage_info")
public class DcChangemanageInfoEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="file_code")
    private String fileCode; // 文件编码
    @TableField(value="file_name")
    private String fileName; // 文件名称
    @TableField(value="file_vsn")
    private String fileVsn; // 版本
    @TableField(value="change_type")
    private Long changeType; // 文件类型（自定义档案需要分项目（CR，FCR,DEN,TA,FCO））
    @TableField(value="arrive_date")
    private Date arriveDate; // 收文日期
    @TableField(value="mgrp")
    private Long mgrp; // 机组--字典pub_mgrp_code
    @TableField(value="specialty")
    private Long specialty; // 专业--字典pub_specialty_code
    @TableField(value="file_attachment")
    private String fileAttachment; // 文件附件
    @TableField(value="is_contract_scope")
    private String isContractScope; // 是否合同范围（Y是/N否）
    @TableField(value="is_entity")
    private String isEntity; // 是否为实体类（Y是/N否）
    @TableField(value="is_material_change")
    private String isMaterialChange; // 是否涉及材料变更（Y是/N否）
    @TableField(value="is_drawquantity_change")
    private String isDrawquantityChange; // 是否变更图纸工程量（Y是/N否）
    @TableField(value="is_claim")
    private String isClaim; // 是否涉及索赔（Y是/N否）
    @TableField(value="claim_file_code")
    private String claimFileCode; // 索赔文件编号
    @TableField(value="is_close")
    private String isClose; // 是否验证关闭
    @TableField(value="close_file_code")
    private String closeFileCode; // 关闭文件编号
    @TableField(value="duty_user_name")
    private String dutyUserName; // 责任人
    @TableField(value="create_dept_id")
    private Long createDeptId; // 创建部门id
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_code")
    private String orgCode; // 组织编码
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 所属组织
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 所属组织编码
    @TableField(value="parent_org_name")
    private String parentOrgName; // 所属组织名称
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="dcChangemanageDrawinfoService")//此处有pid="xxx"，默认值pid="pid"
    private List<DcChangemanageDrawinfoEntity> dcChangemanageDrawinfoList = new ArrayList<>(); // 变更管理受影响图纸信息表
    

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getFileCode() {
        return fileCode;
    }

    public void setFileCode(String fileCode) {
        this.fileCode = fileCode;
    }
    public String getFileName() {
        return fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }
    public String getFileVsn() {
        return fileVsn;
    }

    public void setFileVsn(String fileVsn) {
        this.fileVsn = fileVsn;
    }
    public Long getChangeType() {
        return changeType;
    }

    public void setChangeType(Long changeType) {
        this.changeType = changeType;
    }
    public Date getArriveDate() {
        return arriveDate;
    }

    public void setArriveDate(Date arriveDate) {
        this.arriveDate = arriveDate;
    }
    public Long getMgrp() {
        return mgrp;
    }

    public void setMgrp(Long mgrp) {
        this.mgrp = mgrp;
    }
    public Long getSpecialty() {
        return specialty;
    }

    public void setSpecialty(Long specialty) {
        this.specialty = specialty;
    }
    public String getFileAttachment() {
        return fileAttachment;
    }

    public void setFileAttachment(String fileAttachment) {
        this.fileAttachment = fileAttachment;
    }
    public String getIsContractScope() {
        return isContractScope;
    }

    public void setIsContractScope(String isContractScope) {
        this.isContractScope = isContractScope;
    }
    public String getIsEntity() {
        return isEntity;
    }

    public void setIsEntity(String isEntity) {
        this.isEntity = isEntity;
    }
    public String getIsMaterialChange() {
        return isMaterialChange;
    }

    public void setIsMaterialChange(String isMaterialChange) {
        this.isMaterialChange = isMaterialChange;
    }
    public String getIsDrawquantityChange() {
        return isDrawquantityChange;
    }

    public void setIsDrawquantityChange(String isDrawquantityChange) {
        this.isDrawquantityChange = isDrawquantityChange;
    }
    public String getIsClaim() {
        return isClaim;
    }

    public void setIsClaim(String isClaim) {
        this.isClaim = isClaim;
    }
    public String getClaimFileCode() {
        return claimFileCode;
    }

    public void setClaimFileCode(String claimFileCode) {
        this.claimFileCode = claimFileCode;
    }
    public String getIsClose() {
        return isClose;
    }

    public void setIsClose(String isClose) {
        this.isClose = isClose;
    }
    public String getCloseFileCode() {
        return closeFileCode;
    }

    public void setCloseFileCode(String closeFileCode) {
        this.closeFileCode = closeFileCode;
    }
    public String getDutyUserName() {
        return dutyUserName;
    }

    public void setDutyUserName(String dutyUserName) {
        this.dutyUserName = dutyUserName;
    }
    public Long getCreateDeptId() {
        return createDeptId;
    }

    public void setCreateDeptId(Long createDeptId) {
        this.createDeptId = createDeptId;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    
    public List<DcChangemanageDrawinfoEntity> getDcChangemanageDrawinfoList() {
        return dcChangemanageDrawinfoList;
    }

    public void setDcChangemanageDrawinfoList(List<DcChangemanageDrawinfoEntity> dcChangemanageDrawinfoList) {
        this.dcChangemanageDrawinfoList = dcChangemanageDrawinfoList;
    }
}

==> ejc-ztpcdc-impl-3.0.0-20230811.071921-173-sources.jar: com/ejianc/business/dc/bean/DcChangemanageInfoEntity.java <==
package com.ejianc.business.dc.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.dc.bean.DcChangemanageDrawinfoEntity;
import com.ejianc.business.dc.bean.DcChangemanageInfoEntity;
/**
 * 变更管理表
 * 
 * @author generator
 * 
 */
 @TableName("dc_changemanage_info")
public class DcChangemanageInfoEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="file_code")
    private String fileCode; // 文件编码
    @TableField(value="file_name")
    private String fileName; // 文件名称
    @TableField(value="file_vsn")
    private String fileVsn; // 版本
    @TableField(value="change_type")
    private Long changeType; // 文件类型（自定义档案需要分项目（CR，FCR,DEN,TA,FCO））
    @TableField(value="arrive_date")
    private Date arriveDate; // 收文日期
    @TableField(value="mgrp")
    private Long mgrp; // 机组--字典pub_mgrp_code
    @TableField(value="specialty")
    private Long specialty; // 专业--字典pub_specialty_code
    @TableField(value="file_attachment")
    private String fileAttachment; // 文件附件
    @TableField(value="contract_scope")
    private Boolean contractScope; // 是否合同范围（Y是/N否）
    @TableField(value="entity")
    private Boolean entity; // 是否为实体类（Y是/N否）
    @TableField(value="material_change")
    private Boolean materialChange; // 是否涉及材料变更（Y是/N否）
    @TableField(value="drawquantity_change")
    private Boolean drawquantityChange; // 是否变更图纸工程量（Y是/N否）
    @TableField(value="claim")
    private Boolean claim; // 是否涉及索赔（Y是/N否）
    @TableField(value="claim_file_code")
    private String claimFileCode; // 索赔文件编号
    @TableField(value="close")
    private Boolean close; // 是否验证关闭
    @TableField(value="close_file_code")
    private String closeFileCode; // 关闭文件编号
    @TableField(value="duty_user_name")
    private String dutyUserName; // 责任人
    @TableField(value="create_dept_id")
    private Long createDeptId; // 创建部门id
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_code")
    private String orgCode; // 组织编码
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 所属组织
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 所属组织编码
    @TableField(value="parent_org_name")
    private String parentOrgName; // 所属组织名称
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="dcChangemanageDrawinfoService")//此处有pid="xxx"，默认值pid="pid"
    private List<DcChangemanageDrawinfoEntity> dcChangemanageDrawinfoList = new ArrayList<>(); // 变更管理受影响图纸信息表

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public String getFileCode() {
        return fileCode;
    }

    public void setFileCode(String fileCode) {
        this.fileCode = fileCode;
    }

    public String getFileName() {
        return fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }

    public String getFileVsn() {
        return fileVsn;
    }

    public void setFileVsn(String fileVsn) {
        this.fileVsn = fileVsn;
    }

    public Long getChangeType() {
        return changeType;
    }

    public void setChangeType(Long changeType) {
        this.changeType = changeType;
    }

    public Date getArriveDate() {
        return arriveDate;
    }

    public void setArriveDate(Date arriveDate) {
        this.arriveDate = arriveDate;
    }

    public Long getMgrp() {
        return mgrp;
    }

    public void setMgrp(Long mgrp) {
        this.mgrp = mgrp;
    }

    public Long getSpecialty() {
        return specialty;
    }

    public void setSpecialty(Long specialty) {
        this.specialty = specialty;
    }

    public String getFileAttachment() {
        return fileAttachment;
    }

    public void setFileAttachment(String fileAttachment) {
        this.fileAttachment = fileAttachment;
    }

    public String getClaimFileCode() {
        return claimFileCode;
    }

    public void setClaimFileCode(String claimFileCode) {
        this.claimFileCode = claimFileCode;
    }

    public Boolean getContractScope() {
        return contractScope;
    }

    public void setContractScope(Boolean contractScope) {
        this.contractScope = contractScope;
    }

    public Boolean getEntity() {
        return entity;
    }

    public void setEntity(Boolean entity) {
        this.entity = entity;
    }

    public Boolean getMaterialChange() {
        return materialChange;
    }

    public void setMaterialChange(Boolean materialChange) {
        this.materialChange = materialChange;
    }

    public Boolean getDrawquantityChange() {
        return drawquantityChange;
    }

    public void setDrawquantityChange(Boolean drawquantityChange) {
        this.drawquantityChange = drawquantityChange;
    }

    public Boolean getClaim() {
        return claim;
    }

    public void setClaim(Boolean claim) {
        this.claim = claim;
    }

    public Boolean getClose() {
        return close;
    }

    public void setClose(Boolean close) {
        this.close = close;
    }

    public String getCloseFileCode() {
        return closeFileCode;
    }

    public void setCloseFileCode(String closeFileCode) {
        this.closeFileCode = closeFileCode;
    }

    public String getDutyUserName() {
        return dutyUserName;
    }

    public void setDutyUserName(String dutyUserName) {
        this.dutyUserName = dutyUserName;
    }

    public Long getCreateDeptId() {
        return createDeptId;
    }

    public void setCreateDeptId(Long createDeptId) {
        this.createDeptId = createDeptId;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public List<DcChangemanageDrawinfoEntity> getDcChangemanageDrawinfoList() {
        return dcChangemanageDrawinfoList;
    }

    public void setDcChangemanageDrawinfoList(List<DcChangemanageDrawinfoEntity> dcChangemanageDrawinfoList) {
        this.dcChangemanageDrawinfoList = dcChangemanageDrawinfoList;
    }
}
